# -*- coding: utf-8 -*-
import math
import matplotlib.pyplot as plt
import meca


# Définition des constantes
m = 0.2  # Masse du camion en kg
g = 9.81 # Intensité de la pesanteur en N/kg

# Ici on récupère les données provenant du pointage (enregistrées dans le
# fichier 'mesures.txt' et on les enregistre dans les listes t, X et Z
t, X, Z = meca.extraireDonnees('mesures.txt')

dt = t[1] - t[0]    # Pas temporel (utilisé pour calculer la dérivée)

# Calcul de la dérivé de x et de z pour obtenir les vitesses selon les axes x/z
vX = meca.derive(X,dt)
vZ = meca.derive(Z,dt)

# Ces listes vont contenir les valeurs des différentes énergies
Epp = []
Ec = []
Em = []

# On parcourt les mesures en calculant pour chaque point les 3 énergies
for i in range(len(t)) :
    Epp.append(m * g * Z[i])
    # Le calcul de la vitesse v est nécessaire pour déterminer Ec.
    # math.sqrt(...) correspond à la racine carrée
    v = math.sqrt(vX[i]*vX[i] + vZ[i]*vZ[i])
    Ec.append((1/2)*m*v*v)
    Em.append(Epp[i] + Ec[i])

# Les calculs étant fait, on affiche maintenant les courbes avec pyplot
plt.plot(t,Epp,color='b',marker='+', label = "Epp")
plt.plot(t,Ec,color='r',marker='x', label = "Ec")
plt.plot(t,Em,color='g',marker='o', label = "Em")

plt.grid(True)                     # Affichage de la grille
plt.title("Evolution des énergies au cours du temps")   #Titre de la courbe
plt.xlabel("Temps (s)")                #Titre de l'axe des abscisses
plt.ylabel("Energie (J)")          #titre de l'axe des ordonnées
plt.legend()
xMin,xMax, yMin, yMax = plt.axis()
plt.gca().annotate("", xy=(xMax, 0), xytext=(0, 0),arrowprops=dict(arrowstyle="->"))
plt.gca().annotate("", xy=(0, yMax), xytext=(0, 0),arrowprops=dict(arrowstyle="->"))

plt.show()
